@@ -44,14 +44,14 @@ for data_resolution in ["lsst", "euclid", "hst", "hst_up"]:  # , 'ao']:
         psf_shape_2d=psf_shape_2d,
     )
 
-    mask = al.mask.circular(
+    mask = al.Mask.circular(
         shape_2d=imaging.shape_2d,
         pixel_scales=imaging.pixel_scales,
         sub_size=sub_size,
         radius=radius,
     )
 
-    masked_imaging = al.masked_imaging(imaging=imaging, mask=mask)
+    masked_imaging = al.MaskedImaging(imaging=imaging, mask=mask)
 
     print(
         "Rectangular Inversion fit run times for image type " + data_resolution + "\n"
@@ -152,7 +152,7 @@ for data_resolution in ["lsst", "euclid", "hst", "hst_up"]:  # , 'ao']:
 
     start = time.time()
     for i in range(repeats):
-        al.fit(masked_dataset=masked_imaging, tracer=tracer)
+        al.FitImaging(masked_imaging=masked_imaging, tracer=tracer)
     diff = time.time() - start
     print("Time to perform complete fit = {}".format(diff / repeats))
 
